@@ -12,17 +12,17 @@ from convisoappsec.flowcli.common import project_code_option
     required=False,
 )
 @click.option(
-    '-c',
-    '--current-commit',
-    required=False,
-    help="If no value is set so the HEAD commit from the current branch is used",
-)
-@click.option(
-    '-p',
-    '--previous-commit',
+    '-s',
+    '--start-commit',
     required=False,
     help="If no value is set so the empty tree hash commit is used."
 )
+@click.option(
+    '-e',
+    '--end-commit',
+    required=False,
+    help="If no value is set so the HEAD commit from the current branch is used",
+)
 @click.option(
     '-r',
     '--repository-dir',
@@ -45,8 +45,8 @@ from convisoappsec.flowcli.common import project_code_option
 @help_option
 @pass_flow_context
 def sast(
-    flow_context, project_code, current_commit,
-    previous_commit, repository_dir, send_to_flow
+    flow_context, project_code, end_commit,
+    start_commit, repository_dir, send_to_flow
 ):
     '''
       This command will perform SAST analysis at the source code. The analysis results can
@@ -65,8 +65,8 @@ def sast(
     try:
         git_adapater = GitAdapter(repository_dir)
 
-        current_commit = current_commit if current_commit else git_adapater.head_commit
-        previous_commit = previous_commit if previous_commit else git_adapater.empty_repository_tree_commit
+        end_commit = end_commit if end_commit else git_adapater.head_commit
+        start_commit = start_commit if start_commit else git_adapater.empty_repository_tree_commit
 
         flow = flow_context.create_flow_api_client()
         token = flow.docker_registry.get_sast_token()
@@ -81,7 +81,7 @@ def sast(
         log_func('Starting SASTBox scandiff...')
 
         reports = sastbox.run_scan_diff(
-            repository_dir, current_commit, previous_commit, log=log_func
+            repository_dir, end_commit, start_commit, log=log_func
         )
 
         log_func('SASTBox scandiff done')
@@ -93,7 +93,7 @@ def sast(
         if send_to_flow:
             default_report_type = "sast"
             commit_refs = git_adapater.show_commit_refs(
-                current_commit
+                end_commit
             )
 
             report_names_ctx = click.progressbar(
@@ -142,10 +142,9 @@ Examples:
 
     \b
     1.2 - Running an analysis at specific commit range:
-      $ # running sast at head commit and 5 behind commits
       $ export FLOW_API_KEY='your-api-key'
       $ export FLOW_PROJECT_CODE='your-project-code'
-      $ {command} --current-commit "$(git rev-parse HEAD)" --previous-commit "$(git rev-parse HEAD~5)"
+      $ {command} --start-commit "$(git rev-parse HEAD~5)" --end-commit "$(git rev-parse HEAD)"
 
   \b
   2 - Not Reporting the results to flow api:
@@ -158,9 +157,8 @@ Examples:
 
     \b
     2.2 - Running an analysis at specific commit range:
-      $ # running sast at head commit and 5 behind commits
       $ export FLOW_API_KEY='your-api-key'
-      $ {command} --no-send-to-flow --current-commit "$(git rev-parse HEAD)" --previous-commit "$(git rev-parse HEAD~5)"
+      $ {command} --no-send-to-flow --start-commit "$(git rev-parse HEAD~5)" --end-commit "$(git rev-parse HEAD)"
 
 '''.format(
     command=command,
